==> groupsms_0.1.7.tar.gz: groupsms-0.1.7/groupsms_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="aboutwindow.ui" line="14"/>
        <source>Group SMS - About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="aboutwindow.cpp" line="33"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
</context>
<context>
    <name>ContactsWindow</name>
    <message>
        <location filename="contactswindow.ui" line="14"/>
        <source>Address book</source>
        <translation type="unfinished">Rubrica</translation>
    </message>
    <message>
        <location filename="contactswindow.ui" line="32"/>
        <source>Find:</source>
        <translation type="unfinished">Cerca:</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="36"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="88"/>
        <location filename="contactswindow.cpp" line="180"/>
        <source>Address book (%1)</source>
        <translation type="unfinished">Rubrica (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWindow</name>
    <message>
        <location filename="editgroupwindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="47"/>
        <source>Name:</source>
        <translation type="unfinished">Nome:</translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="61"/>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="34"/>
        <source>Edit group</source>
        <translation type="unfinished">Modifica Gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="36"/>
        <source>New group</source>
        <translation type="unfinished">Nuovo Gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="54"/>
        <source>Enter a group name</source>
        <translation type="unfinished">Inserisci il nome del gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="60"/>
        <source>A group named &apos;%1&apos; exists.</source>
        <translation type="unfinished">Un gruppo chiamato &apos;%1&apos; esiste già.</translation>
    </message>
</context>
<context>
    <name>GroupActionsWindow</name>
    <message>
        <location filename="groupactionswindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="45"/>
        <source>Select all</source>
        <translation type="unfinished">Seleziona tutti</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="48"/>
        <source>Deselect all</source>
        <translation type="unfinished">Deseleziona tutti</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="51"/>
        <source>Remove contact</source>
        <translation type="unfinished">Rimuovi contatto</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="147"/>
        <location filename="groupactionswindow.cpp" line="252"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="148"/>
        <source>Remove %1 contacts from group %2?</source>
        <translation type="unfinished">Rimuovere %1 contatti dal gruppo %2?</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="253"/>
        <source>Remove 1 contact from group %1?</source>
        <oldsource>Remove 1 contact from group %2?</oldsource>
        <translation type="unfinished">Rimuovere 1 contatto dal gruppo %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="27"/>
        <source>Add new group</source>
        <translation type="unfinished">Aggiungi gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="46"/>
        <source>Group SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="47"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="51"/>
        <source>Exit</source>
        <translation type="unfinished">Esci</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="58"/>
        <source>Remove group</source>
        <translation type="unfinished">Cancella gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="61"/>
        <source>Send SMS to group</source>
        <translation type="unfinished">Invia SMS al gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="221"/>
        <location filename="mainwindow.cpp" line="263"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="222"/>
        <source>You have %1 invalid number(s) in your groups.
Remove invalid numbers?</source>
        <translation type="unfinished">Ci sono %1 numeri non validi nei tuoi gruppi.
Rimuovere i numeri non validi?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="264"/>
        <source>Remove group %1?</source>
        <translation type="unfinished">Rimuovere il gruppo %1?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="commonstatic.cpp" line="34"/>
        <source>Confirm</source>
        <translation type="unfinished">Conferma</translation>
    </message>
</context>
</TS>

==> groupsms_0.2.1.tar.gz: groupsms-0.2.1/groupsms_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="aboutwindow.ui" line="14"/>
        <source>Group SMS - About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="aboutwindow.cpp" line="33"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
</context>
<context>
    <name>ContactsWindow</name>
    <message>
        <location filename="contactswindow.ui" line="14"/>
        <source>Address book</source>
        <translation type="unfinished">Rubrica</translation>
    </message>
    <message>
        <location filename="contactswindow.ui" line="32"/>
        <source>Find:</source>
        <translation type="unfinished">Cerca:</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="36"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="85"/>
        <location filename="contactswindow.cpp" line="126"/>
        <source>Address book (%1)</source>
        <translation type="unfinished">Rubrica (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWindow</name>
    <message>
        <location filename="editgroupwindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="47"/>
        <source>Name:</source>
        <translation type="unfinished">Nome:</translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="61"/>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="34"/>
        <source>Edit group</source>
        <translation type="unfinished">Modifica gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="36"/>
        <source>New group</source>
        <translation type="unfinished">Nuovo gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="54"/>
        <source>Enter a group name</source>
        <translation type="unfinished">Inserisci il nome del gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="60"/>
        <source>A group named &apos;%1&apos; exists.</source>
        <translation type="unfinished">Un gruppo chiamato &apos;%1&apos; esiste già.</translation>
    </message>
</context>
<context>
    <name>GroupActionsWindow</name>
    <message>
        <location filename="groupactionswindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="43"/>
        <source>Select all</source>
        <translation type="unfinished">Seleziona tutti</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="46"/>
        <source>Deselect all</source>
        <translation type="unfinished">Deseleziona tutti</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="49"/>
        <source>Remove contact</source>
        <translation type="unfinished">Rimuovi contatto</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="140"/>
        <location filename="groupactionswindow.cpp" line="232"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="141"/>
        <source>Remove %1 contacts from group %2?</source>
        <translation type="unfinished">Rimuovere %1 contatti dal gruppo %2?</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="233"/>
        <source>Remove 1 contact from group %1?</source>
        <oldsource>Remove 1 contact from group %2?</oldsource>
        <translation type="unfinished">Rimuovere 1 contatto dal gruppo %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="27"/>
        <source>Add new group</source>
        <translation type="unfinished">Aggiungi gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="50"/>
        <source>Group SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="51"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="55"/>
        <source>Templates</source>
        <translation type="unfinished">Modelli</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="59"/>
        <source>Exit</source>
        <translation type="unfinished">Esci</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="66"/>
        <source>Remove group</source>
        <translation type="unfinished">Cancella gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="69"/>
        <source>Send SMS to group</source>
        <translation type="unfinished">Invia SMS al gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="275"/>
        <location filename="mainwindow.cpp" line="317"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="276"/>
        <source>You have %1 invalid number(s) in your groups.
Remove invalid numbers?</source>
        <translation type="unfinished">Ci sono %1 numeri non validi nei tuoi gruppi.
Rimuovere i numeri non validi?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="318"/>
        <source>Remove group %1?</source>
        <translation type="unfinished">Rimuovere il gruppo %1?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="commonstatic.cpp" line="37"/>
        <source>Confirm</source>
        <translation type="unfinished">Conferma</translation>
    </message>
</context>
<context>
    <name>SendWindow</name>
    <message>
        <location filename="sendwindow.ui" line="14"/>
        <source>Send Message</source>
        <translation type="unfinished">Invio Messaggio</translation>
    </message>
    <message>
        <location filename="sendwindow.ui" line="66"/>
        <source>Templates</source>
        <translation type="unfinished">Modelli</translation>
    </message>
    <message>
        <location filename="sendwindow.ui" line="88"/>
        <source>Subject:</source>
        <translation type="unfinished">Soggetto:</translation>
    </message>
</context>
<context>
    <name>TemplateWindow</name>
    <message>
        <location filename="templatewindow.ui" line="14"/>
        <source>Template</source>
        <translation type="unfinished">Modello</translation>
    </message>
    <message>
        <location filename="templatewindow.ui" line="34"/>
        <source>Subject:</source>
        <translation type="unfinished">Soggetto:</translation>
    </message>
    <message>
        <location filename="templatewindow.cpp" line="29"/>
        <source>Edit template</source>
        <translation type="unfinished">Modifica modello</translation>
    </message>
    <message>
        <location filename="templatewindow.cpp" line="31"/>
        <source>New template</source>
        <translation type="unfinished">Nuovo modello</translation>
    </message>
    <message>
        <location filename="templatewindow.cpp" line="46"/>
        <source>Enter a text</source>
        <translation type="unfinished">Inserisci il testo del modello</translation>
    </message>
    <message>
        <location filename="templatewindow.cpp" line="53"/>
        <source>Error saving template</source>
        <translation type="unfinished">Errore nel salvataggio del modello</translation>
    </message>
</context>
<context>
    <name>TemplatesWindow</name>
    <message>
        <location filename="templateswindow.ui" line="14"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="templateswindow.cpp" line="91"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="templateswindow.cpp" line="92"/>
        <source>Remove the selected template?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
